@@ -6,15 +6,17 @@ Apache::Pod - base class for converting Pod files to prettier forms
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
-    $Header: /home/cvs/apache-pod/lib/Apache/Pod.pm,v 1.4 2002/09/28 17:20:50 andy Exp $
+    $Header: /home/cvs/apache-pod/lib/Apache/Pod.pm,v 1.5 2002/09/30 04:42:05 andy Exp $
 
 =cut
 
 use vars qw( $VERSION );
+use strict;
+eval 'use warnings' if $] >= 5.006;
 
-$VERSION = '0.01_01';
+$VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -34,32 +36,38 @@ he'd like from the URL, such as
 
 =head1 FUNCTIONS
 
-No functions are exported.  I don't want to dink around with Exporter in mod_perl if I don't need to.
+No functions are exported.  I don't want to dink around with Exporter
+in mod_perl if I don't need to.
 
-=head2 C<< getpod( I<$r> ) >>
+=head2 C<< getpodfile( I<$r> ) >>
 
-Returns the filename requested off of the C<$r> request object.
+Returns the filename requested off of the C<$r> request object, or what
+Perldoc would find, based on Pod::Find.
 
 =cut
 
-sub getpod {
+use Pod::Find;
+
+sub getpodfile {
     my $r = shift;
 
-    my $pod;
+    my $filename;
 
     if ($r->filename =~ m/\.pod$/i) {
-        $pod = $r->filename;
+        $filename = $r->filename;
     } else {
-        $pod = $r->path_info;
-        $pod =~ s|/||;
-        $pod =~ s|/|::|g;
-        $pod =~ s|\.html$||;  # Intermodule links end with .html
+        my $module = $r->path_info;
+        $module =~ s|/||;
+        $module =~ s|/|::|g;
+        $module =~ s|\.html?$||;  # Intermodule links end with .html
+
+	$filename = Pod::Find::pod_where( {-inc=>1}, $module );
+
+	# XXX Unimplemented
+	# $pod =~ s/^f::/-f /;    # If we specify /f/ as our "base", it's a function search
     }
 
-    # XXX Unimplemented
-    # $pod =~ s/^f::/-f /;    # If we specify /f/ as our "base", it's a function search
-
-    return $pod;
+    return $filename;
 }
 
 1;
