@@ -6,15 +6,17 @@ Apache::Pod::Text - mod_perl handler to convert Pod to plain text
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
-    $Header: /home/cvs/apache-pod/lib/Apache/Pod/Text.pm,v 1.2 2002/09/28 17:20:50 andy Exp $
+    $Header: /home/cvs/apache-pod/lib/Apache/Pod/Text.pm,v 1.3 2002/09/30 04:42:05 andy Exp $
 
 =cut
 
+use strict;
+eval 'use warnings' if $] >= 5.006;
 use vars qw( $VERSION );
 
-$VERSION = '0.01_01';
+$VERSION = '0.02';
 
 =head1 SYNOPSIS
 
